==> scikit_hep_repo_review-0.5.0.tar.gz: scikit_hep_repo_review-0.5.0/noxfile.py <==
from __future__ import annotations

import shutil
from pathlib import Path

import nox

DIR = Path(__file__).parent.resolve()

nox.options.sessions = ["lint", "pylint", "tests"]


@nox.session(reuse_venv=True)
def run(session: nox.Session) -> None:
    """
    Run the program
    """

    session.install("-e", ".[cli]")
    session.run("python", "-m", "scikit_hep_repo_review", *session.posargs)


@nox.session
def lint(session: nox.Session) -> None:
    """
    Run the linter.
    """
    session.install("pre-commit")
    session.run("pre-commit", "run", "--all-files", *session.posargs)


@nox.session
def pylint(session: nox.Session) -> None:
    """
    Run PyLint.
    """
    # This needs to be installed into the package environment, and is slower
    # than a pre-commit check
    session.install(".[cli]", "pylint")
    session.run("pylint", "src", *session.posargs)


@nox.session
def tests(session: nox.Session) -> None:
    """
    Run the unit and regular tests.
    """
    session.install(".[test]")
    session.run("pytest", *session.posargs)


@nox.session(reuse_venv=True)
def build(session: nox.Session) -> None:
    """
    Build an SDist and wheel.
    """

    build_p = DIR.joinpath("build")
    if build_p.exists():
        shutil.rmtree(build_p)

    session.install("build")
    session.run("python", "-m", "build")


@nox.session(venv_backend="none")
def serve(session: nox.Session) -> None:
    """
    Serve the webapp.
    """

    session.cd("docs")
    session.log("Serving on http://localhost:8080")
    session.run("python3", "-m", "http.server", "8080")

==> scikit_hep_repo_review-0.6.0.tar.gz: scikit_hep_repo_review-0.6.0/noxfile.py <==
from __future__ import annotations

import shutil
from pathlib import Path

import nox

DIR = Path(__file__).parent.resolve()

nox.options.sessions = ["lint", "pylint", "tests"]


@nox.session(reuse_venv=True)
def run(session: nox.Session) -> None:
    """
    Run the program
    """

    session.install("-e", ".[cli]")
    session.run("python", "-m", "scikit_hep_repo_review", *session.posargs)


@nox.session
def lint(session: nox.Session) -> None:
    """
    Run the linter.
    """
    session.install("pre-commit")
    session.run("pre-commit", "run", "--all-files", *session.posargs)


@nox.session
def pylint(session: nox.Session) -> None:
    """
    Run PyLint.
    """
    # This needs to be installed into the package environment, and is slower
    # than a pre-commit check
    session.install("-e.[cli]", "pylint")
    session.run("pylint", "src", *session.posargs)


@nox.session
def tests(session: nox.Session) -> None:
    """
    Run the unit and regular tests.
    """
    session.install("-e.[test,cli]")
    session.run("pytest", *session.posargs)


@nox.session(reuse_venv=True)
def build(session: nox.Session) -> None:
    """
    Build an SDist and wheel.
    """

    build_p = DIR.joinpath("build")
    if build_p.exists():
        shutil.rmtree(build_p)

    session.install("build")
    session.run("python", "-m", "build")


@nox.session(venv_backend="none")
def serve(session: nox.Session) -> None:
    """
    Serve the webapp.
    """

    session.cd("docs")
    session.log("Serving on http://localhost:8080")
    session.run("python3", "-m", "http.server", "8080")
